import argparse
import printFibonacci
if __name__ == '__main__':
    parser = argparse.ArgumentParser(
        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
        description='example')

    parser.add_argument('-n', '--index_of_fib', type=int, help='exporter ips list: "index_of_fib',
                        required=True)

    args= parser.parse_args()
    n = args.index_of_fib
    printFibonacci.getFibonacciCisco(n)


from setuptools import setup, find_packages


setup(
    name='fibonacci_cisco',
    version='0.1.2',
    license='MIT',
    author="example example",
    author_email='email@example.com',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    url="",
    keywords='example project',
    install_requires=[],

)


def getFibonacciNumber(n):
    if n < 0:
        raise Exception("n must be non negative number")
    saveNumbers = {0: 0, 1: 1}
    for i in range(2, n + 1):
        saveNumbers[i] = saveNumbers[i - 1] + saveNumbers[i - 2]
    return saveNumbers[n]

def getFibonacciCisco(n):
    numberOfPrints = getFibonacciNumber(n)
    for i in range(1,numberOfPrints+1):
        print(f"Cisco {i}")
    return

